@@ -33,10 +33,6 @@ def get_missing_pdf_libs():
     missing = ""
     if not xml2rfc.HAVE_WEASYPRINT:
         missing += "\nCould not import weasyprint"
-    if not xml2rfc.HAVE_PYCAIRO:
-        missing += "\nCould not import pycairo"
-    if not xml2rfc.HAVE_CAIRO:
-        missing += "\nCould not find the cairo lib"
     if not xml2rfc.HAVE_PANGO:
         missing += "\nCould not find the pango lib"
     return missing
@@ -84,29 +80,14 @@ def get_pdf_help(missing_libs=""):
     In order to generate PDFs, xml2rfc uses the WeasyPrint library, which
     depends on external libaries that must be installed as native packages.
 
-    1. First, install the Cairo, Pango, and GDK-PixBuf library files on your
+    1. First, install the Pango, and other required libraries on your
     system.  See installation instructions on the WeasyPrint Docs:
     
-        https://weasyprint.readthedocs.io/en/stable/install.html
+        https://doc.courtbouillon.org/weasyprint/stable/first_steps.html
 
-    (Python 3 is not needed if your system Python is 2.7, though).
+    2. Next, install weasyprint python modules using pip.
 
-
-    2. Next, install the pycairo and weasyprint python modules using pip.
-    Depending on your system, you may need to use 'sudo' or install in
-    user-specific directories, using the --user switch.  On OS X in
-    particular, you may also need to install a newer version of setuptools
-    using --user before weasyprint can be installed.  If you install with 
-    the --user switch, you may need to also set PYTHONPATH, e.g.,
-    
-        PYTHONPATH=/Users/username/Library/Python/2.7/lib/python/site-packages
-
-    for Python 2.7.
-
-    The basic pip commands (modify as needed according to the text above)
-    are:
-
-        pip install 'pycairo>=1.18' 'weasyprint<=0.42.3'
+        pip install 'weasyprint>=53.0'
 
 
     3. Finally, install the full Noto Font and Roboto Mono packages:
@@ -212,7 +193,7 @@ def main():
                            help='outputs formatted HTML to file')
     formatgroup.add_argument('--nroff', action='store_true',
                            help='outputs formatted nroff to file (only v2 input)')
-    if xml2rfc.HAVE_CAIRO and xml2rfc.HAVE_PANGO:
+    if xml2rfc.HAVE_PANGO:
         formatgroup.add_argument('--pdf', action='store_true',
                                help='outputs formatted PDF to file')
     else:
@@ -265,7 +246,7 @@ def main():
     value_options.add_argument(      '--config-file', dest="config_file", metavar='FILE', is_config_file_arg=True,
                             help='specify a configuration file')
     value_options.add_argument('-d', '--dtd', dest='dtd', metavar='DTDFILE', help='specify an alternate dtd file')
-    value_options.add_argument('-D', '--date', dest='datestring', metavar='DATE', default=datetime.date.today(),
+    value_options.add_argument('-D', '--date', dest='datestring', metavar='DATE', default=None,
                             help="run as if the date is DATE (format: yyyy-mm-dd).  Default: Today's date")
     value_options.add_argument('-f', '--filename', dest='filename', metavar='FILE',
                             help='Deprecated.  The same as -o')
@@ -334,6 +315,8 @@ def main():
                            help=configargparse.SUPPRESS),
     htmloptions.add_argument('--no-inline-version-info', action='store_false', dest="inline_version_info",
                            help=configargparse.SUPPRESS),
+    htmloptions.add_argument('--no-rfc-local', action='store_false', dest='rfc_local', default=True,
+                             help='Do not link to rfc-local.css')
 
     v2v3options = optionparser.add_argument_group('V2-V3 Converter Options')
     v2v3options.add_argument('--add-xinclude', action='store_true',
@@ -498,14 +481,12 @@ def main():
                 print('Cache directory is not writable: %s' % options.cache)
                 sys.exit(1)
     #
-    if options.datestring:
-        if isinstance(options.datestring, str):
-            options.date = datetime.datetime.strptime(options.datestring, "%Y-%m-%d").date()
-        elif isinstance(options.datestring, datetime.date):
-            options.date = options.datestring
-        else:
-            xml2rfc.log.warn("Unexpected type for options.datestring: %s" % type(options.datestring))
+    if options.datestring is not None:
+        options.date = datetime.datetime.strptime(options.datestring, "%Y-%m-%d").date()
     else:
+        # Use today by default. Even though date = None is later translated to today(), set it
+        # explicitly to ensure there's no date skew between instance inits if we happen to be run
+        # exactly at midnight.
         options.date = datetime.date.today()
 
     if options.omit_headers and not options.text:
