@@ -2,15 +2,12 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals, print_function, division
 
-import datetime
 import io
 import logging
 import os
 
 import warnings
 
-warnings.filterwarnings("ignore", message='There are known rendering problems with Cairo <= 1.14.0')
-warnings.filterwarnings("ignore", message='There are known rendering problems and missing features with cairo < 1.15.4')
 warnings.filterwarnings("ignore", message='@font-face support needs Pango >= 1.38')
 
 try:
@@ -38,13 +35,15 @@ except ImportError:
 
 class PdfWriter(BaseV3Writer):
 
-    def __init__(self, xmlrfc, quiet=None, options=default_options, date=datetime.date.today()):
+    def __init__(self, xmlrfc, quiet=None, options=default_options, date=None):
         super(PdfWriter, self).__init__(xmlrfc, quiet=quiet, options=options, date=date)
         if not weasyprint:
             self.err(None, "Cannot run PDF formatter: %s" % import_error)
             return
 
         logging.basicConfig(level=logging.INFO)
+
+        # Weasyprint logger
         wplogger = logging.getLogger('weasyprint')
         if   self.options.quiet:
             wplogger.setLevel(logging.CRITICAL)
@@ -53,6 +52,15 @@ class PdfWriter(BaseV3Writer):
         else:
             wplogger.setLevel(logging.ERROR)
 
+        # fontTools logger
+        ftlogger = logging.getLogger('fontTools')
+        if self.options.quiet:
+            ftlogger.setLevel(logging.CRITICAL)
+        elif self.options.verbose:
+            ftlogger.setLevel(logging.WARNING)
+        else:
+            ftlogger.setLevel(logging.ERROR)
+
     def pdf(self):
         if not weasyprint:
             return None
